==> deepin-font-manager_5.9.6.orig.tar.xz: deepin-font-manager-5.9.6/translations/deepin-font-manager_da.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>Alle skrifttyper</translation>
    </message>
    <message>
        <source>System</source>
        <translation>System</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Bruger</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Favoritter</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Aktiv</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>Kinesisk</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>Med fast bredde</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annuller</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Slet</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation>Aktivér</translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation>Deaktivér</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Annuller</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>Beskadiget fil</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Samme version er installeret</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>Systemets skrifttype</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Skift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation>Skrifttyper</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>%1 skrifttype installeret</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>%1 skrifttyper installeret</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DFontWidget</name>
    <message>
        <source>Broken file</source>
        <translation>Beskadiget fil</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>This font will not be available to applications</source>
        <translation>Skrifttypen vil ikke være tilgængelig for programmer</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>Skrifttyperne vil ikke være tilgængelig for programmer</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Slet</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>Sletter skrifttyper, vent venligst...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>Verificering af skrifttype</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>Ingen skrifttyper at installere</translation>
    </message>
    <message>
        <source>Exit</source>
        <comment>button</comment>
        <translation>Afslut</translation>
    </message>
    <message>
        <source>Continue</source>
        <comment>button</comment>
        <translation>Fortsæt</translation>
    </message>
</context>
<context>
    <name>Font</name>
    <message>
        <source>Don&apos;t let your dreams be dreams</source>
        <translation>Lad dine drømme blive virkelighed</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>Grundlæggende information</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Stil</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Beskrivelse</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Ukendt</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>Fulde navn</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>Ps-navn</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>Varemærke</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>Skrifttypehåndtering</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>Skrifttypehåndtering hjælper brugere med at installere og håndtere skrifttyper.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>Indlæser skrifttyper, vent venligst...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>Skrifttypen blev eksporteret til dit skrivebord</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>%1 skrifttyper blev eksporteret til dit skrivebord</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>Tilføj skrifttype</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Aktivér</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Deaktivér</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Slet</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorit til</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Favorit fra</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detaljer</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Vis i filhåndtering</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Eksportér</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>deaktiveret</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>Skrifttyperne er blevet deaktiveret</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>Installer skrifttype</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>Verificerer...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>Ukendt</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>Beskadiget fil</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>Installeret</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>Ikke installeret</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>Installer skrifttype</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>Søg</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>Ingen søgeresultater</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>Ingen skrifttyper</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Hjælp</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Vis genveje</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Side op</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Side ned</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Slet</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Tilføj skrifttype</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorit til</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Favorit fra</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>Skrifttypeinformation</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>Indtast tekst til forhåndsvisning</translation>
    </message>
</context>
</TS>

==> deepin-font-manager_5.9.14.orig.tar.xz: deepin-font-manager-5.9.14/translations/deepin-font-manager_da.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="da">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>Alle skrifttyper</translation>
    </message>
    <message>
        <source>System</source>
        <translation>System</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Bruger</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Favoritter</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Aktiv</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>Kinesisk</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>Med fast bredde</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annuller</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Slet</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation>Aktivér</translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation>Deaktivér</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuller</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>Beskadiget fil</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Samme version er installeret</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>Systemets skrifttype</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Skift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>%1 skrifttype installeret</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>%1 skrifttyper installeret</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to install %1 font. There is not enough disk space.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to install %1 fonts. There is not enough disk space.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>This font will not be available to applications</source>
        <translation>Skrifttypen vil ikke være tilgængelig for programmer</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>Skrifttyperne vil ikke være tilgængelig for programmer</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Slet</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>Sletter skrifttyper, vent venligst...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>Verificering af skrifttype</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>Ingen skrifttyper at installere</translation>
    </message>
    <message>
        <source>Exit</source>
        <comment>button</comment>
        <translation>Afslut</translation>
    </message>
    <message>
        <source>Continue</source>
        <comment>button</comment>
        <translation>Fortsæt</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>Grundlæggende information</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Stil</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Beskrivelse</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Ukendt</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>Fulde navn</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>Ps-navn</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>Varemærke</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>Skrifttypehåndtering</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>Skrifttypehåndtering hjælper brugere med at installere og håndtere skrifttyper.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>Indlæser skrifttyper, vent venligst...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>Skrifttypen blev eksporteret til dit skrivebord</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>%1 skrifttyper blev eksporteret til dit skrivebord</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>Tilføj skrifttype</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Aktivér</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Deaktivér</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Slet</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorit til</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Favorit fra</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detaljer</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Vis i filhåndtering</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Eksportér</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>deaktiveret</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>Skrifttyperne er blevet deaktiveret</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>Installer skrifttype</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>Verificerer...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>Ukendt</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>Beskadiget fil</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>Installeret</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>Ikke installeret</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>Installer skrifttype</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>Søg</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>Ingen søgeresultater</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>Ingen skrifttyper</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Hjælp</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Vis genveje</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Side op</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Side ned</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Slet</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Tilføj skrifttype</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorit til</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Favorit fra</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>Skrifttypeinformation</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>Indtast tekst til forhåndsvisning</translation>
    </message>
</context>
</TS>
